==> qtjambi-qml-debuginfo-windows-x64-5.15.17.jar: sources/QtJambiQml/QQmlComponent_shell.h <==
#ifndef QQMLCOMPONENT_SHELL_H
#define QQMLCOMPONENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlcomponent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/QmlAPI>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlincubator.h>
#include <QtJambi/RegistryAPI>


class QQmlComponent_shell : public QQmlComponent, public QtJambiShellInterface
{
public:
    QQmlComponent_shell(QObject* parent0 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, QObject* parent1 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QString& fileName1, QObject* parent2 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QString& fileName1, QQmlComponent::CompilationMode mode2, QObject* parent3 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QUrl& url1, QObject* parent2 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QUrl& url1, QQmlComponent::CompilationMode mode2, QObject* parent3 = nullptr);
    ~QQmlComponent_shell() override;

    QObject* beginCreate(QQmlContext* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void completeCreate() override;
    void connectNotify(const QMetaMethod& signal0) override;
    QObject* create(QQmlContext* context0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlComponent_access : public QQmlComponent
{
    jobject __qt_beginCreate_QQmlContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_completeCreate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_create_QQmlContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID context0);
};

#endif // QQMLCOMPONENT_SHELL_H

==> qtjambi-qml-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiQml/QQmlComponent_shell.h <==
#ifndef QQMLCOMPONENT_SHELL_H
#define QQMLCOMPONENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtQml/qqmlcomponent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtJambi/QmlAPI>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmlerror.h>
#include <QtQml/qqmlincubator.h>
#include <QtJambi/RegistryAPI>


class QQmlComponent_shell : public QQmlComponent, public QtJambiShellInterface
{
public:
    QQmlComponent_shell(QObject* parent0 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, QObject* parent1 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QString& fileName1, QObject* parent2 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QString& fileName1, QQmlComponent::CompilationMode mode2, QObject* parent3 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QUrl& url1, QObject* parent2 = nullptr);
    QQmlComponent_shell(QQmlEngine* arg__1, const QUrl& url1, QQmlComponent::CompilationMode mode2, QObject* parent3 = nullptr);
    QQmlComponent_shell(QQmlEngine* engine0, QAnyStringView uri1, QAnyStringView typeName2, QObject* parent3 = nullptr);
    QQmlComponent_shell(QQmlEngine* engine0, QAnyStringView uri1, QAnyStringView typeName2, QQmlComponent::CompilationMode mode3, QObject* parent4 = nullptr);
    ~QQmlComponent_shell() override;

    QObject* beginCreate(QQmlContext* arg__1) override;
    void childEvent(QChildEvent* event0) override;
    void completeCreate() override;
    void connectNotify(const QMetaMethod& signal0) override;
    QObject* create(QQmlContext* context0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlComponent_access : public QQmlComponent
{
    jobject __qt_createObject_QObject_ptr_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, jobject properties1);
    jobject __qt_beginCreate_QQmlContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_completeCreate(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_create_QQmlContext_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID context0);
};

#endif // QQMLCOMPONENT_SHELL_H
